@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2013 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See the COPYING
@@ -56,6 +56,8 @@ void info_mod(struct xmp_module_info *mi)
 	for (i = 0; i < mi->mod->chn; i++) {
 		if (mi->mod->xxc[i].flg & XMP_CHANNEL_SYNTH) {
 			report("S ");
+		} else if (mi->mod->xxc[i].flg & XMP_CHANNEL_MUTE) {
+			report("- ");
 		} else {
 			report("%x ", mi->mod->xxc[i].pan >> 4);
 		}
@@ -130,7 +132,7 @@ void info_frame(struct xmp_module_info *mi, struct xmp_frame_info *fi, struct co
 			ctl->explore ? 'Z' : ' ',
 			ctl->loop ? 'L' : ' ',
 			ctl->loop > 1 ? '*' : ' ');
-		msg_timer -= fi->frame_time;
+		msg_timer -= fi->frame_time * fi->speed / 6;
 		if (msg_timer == 0)
 			msg_timer--;
 		else
@@ -186,7 +188,7 @@ void info_ins_smp(struct xmp_module_info *mi)
 			continue;
 		}
 
-		report("%02x %-32.32s ", i, ins->name);
+		report("%02x %-32.32s ", i + 1, ins->name);
 
 		for (j = 0; j < ins->nsm; j++) {
 			struct xmp_subinstrument *sub = &ins->sub[j];
@@ -200,7 +202,7 @@ void info_ins_smp(struct xmp_module_info *mi)
 			}
 
 			report("[%02x] %05x%c%05x %05x%c V%02x %+04d %+03d P%02x\n",
-				sub->sid,
+				sub->sid + 1,
 				smp->len,
 				smp->flg & XMP_SAMPLE_16BIT ? '+' : ' ',
 				smp->lps,
@@ -235,8 +237,8 @@ void info_instruments(struct xmp_module_info *mi)
 			continue;
 		}
 
-		report("%02x %-32.32s %02x %04x %c%c%c %02x ", i, ins->name,
-			ins->vol, ins->rls,
+		report("%02x %-32.32s %02x %04x %c%c%c %02x ",
+			i + 1, ins->name, ins->vol, ins->rls,
 			ins->aei.flg & XMP_ENVELOPE_ON ? 'A' : '-',
 			ins->fei.flg & XMP_ENVELOPE_ON ? 'F' : '-',
 			ins->pei.flg & XMP_ENVELOPE_ON ? 'P' : '-',
@@ -255,7 +257,7 @@ void info_instruments(struct xmp_module_info *mi)
 			}
 
 			report("[%02x] %02x %02x %+04d %+03d P%02x %02x\n",
-				j,
+				j + 1,
 				sub->gvl,
 				sub->vol,
 				sub->fin,
@@ -286,7 +288,7 @@ void info_samples(struct xmp_module_info *mi)
 		}
 
 		report("%02x %-32.32s %06x %06x %06x %s %s %s\n",
-			i, smp->name,
+			i + 1, smp->name,
 			smp->len,
 			smp->lps,
 			smp->lpe,
