@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2013 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See the COPYING
@@ -264,7 +264,7 @@ int main(int argc, char **argv)
 
 	if (opt.verbose > 0) {
 		report("Extended Module Player " VERSION "\n"
-			"Copyright (C) 1996-2013 Claudio Matsuoka and Hipolito Carraro Jr\n");
+			"Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr\n");
 
 		report("Using %s\n", sound->description);
 
@@ -296,6 +296,10 @@ int main(int argc, char **argv)
 #endif
 
 	xc = xmp_create_context();
+	if (xc == NULL) {
+		perror(argv[0]);
+		exit(EXIT_FAILURE);
+	}
 
 	skipprev = 0;
 
@@ -322,7 +326,7 @@ int main(int argc, char **argv)
 			if (lf_flag)
 				report("\n");
 			lf_flag = 1;
-			report("Loading %s... (%d of %d)\n",
+			report("Loading %s (%d of %d)\n",
 				argv[optind], optind - first + 1, argc - first);
 		}
 
